/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.scriptinterpreter;

import java.io.PrintStream;

/**
 * <p>ExecutionLogger interface.</p>
 *
 * @author Olivier Lamy
 */
public interface ExecutionLogger {
    /**
     * The stream which will catch the output of the {@link org.apache.maven.shared.scriptinterpreter.ScriptRunner}.
     *
     * @return the output stream
     */
    PrintStream getPrintStream();

    /**
     * Consume logging from this component.
     *
     * @param line the line to consume
     */
    void consumeLine(String line);
}
